@@ -4,7 +4,6 @@ FORMAT = '--format'
 LOG_FILE = '--log-file'
 LOG_FORMAT = '--log-format'
 LOG_LEVEL = '--log-level'
-TIMEOUT = '--timeout'
 BUILD_CACHE_PATH = '--build-cache-path'
 BUILD_PATH = '--build-path'
 BUILD_PROPERTY = '--build-property'
@@ -48,3 +47,18 @@ GIT_URL = '--git-url'
 ZIP_PATH = '--zip-path'
 ONLY_COMPILATION_DATABASE = '--only-compilation-database'
 LIBRARY = '--library'
+DISCOVERY_TIMEOUT = '--discovery-timeout'
+PROTOCOL = '--protocol'
+NO_COLOR = '--no-color'
+DEBUG = '--debug'
+DEBUG_FILTER = '--debug-filter'
+CONFIG = '--config'
+DESCRIBE = '--describe'
+QUIET = '--quiet'
+BOARD_OPTIONS = '--board-options'
+ENCRYPT_KEY = '--encrypt-key'
+KEYS_KEYCHAIN = '--keys-keychain'
+SIGN_KEY = '--sign-key'
+DEBUG_FILE = '--debug-file'
+DUMP_PROFILE = '--dump-profile'
+PROFILE = '--profile'
